@@ -39,8 +39,6 @@ class ResponseDownloaderByRequests(ResponseDownloader):
 
         # 是否保持 cookie
         if not self.keep_session and self.keep_cookie:
-            if self.cookies:
-                self.cookie_jar.update(self.cookies)
             self.cookies = self.cookie_jar
 
         return request.request(
