@@ -111,35 +111,35 @@ class DistributiveSpider(Spider):
                     continue
 
                 # 添加 downloader
-                downloader = request['downloader']
-                key = downloader['module'] + '.' + downloader['init']
-                if key not in modules:
-                    cls = importlib.import_module(downloader['module']).__getattribute__(downloader['init'])  # 导入
-                    modules[key] = cls
-                else:
-                    cls = modules[key]
+                if 'downloader' in request:
+                    downloader = request['downloader']
+                    key = downloader['module'] + '.' + downloader['init']
+                    if key not in modules:
+                        cls = importlib.import_module(downloader['module']).__getattribute__(downloader['init'])  # 导入
+                        modules[key] = cls
+                    else:
+                        cls = modules[key]
 
-                request['downloader'] = cls
+                    request['downloader'] = cls
 
                 # downloader_parser
-                downloader_parser = request['downloader_parser']
-                key = downloader_parser['module'] + '.' + downloader_parser['init']
-                if key not in modules:
-                    cls = importlib.import_module(downloader_parser['module']).__getattribute__(
-                        downloader_parser['init'])  # 导入
-                    modules[key] = cls
-                else:
-                    cls = modules[key]
+                if 'downloader_parser' in request:
+                    downloader_parser = request['downloader_parser']
+                    key = downloader_parser['module'] + '.' + downloader_parser['init']
+                    if key not in modules:
+                        cls = importlib.import_module(downloader_parser['module']).__getattribute__(
+                            downloader_parser['init'])  # 导入
+                        modules[key] = cls
+                    else:
+                        cls = modules[key]
 
-                request['downloader_parser'] = cls
+                    request['downloader_parser'] = cls
 
                 # 重构请求
                 request = Request(**request)
 
-                # 为每一个起始函数添加一个 session、cookie_jar
+                # 为每一个起始函数添加一个 cookie_jar
                 request.cookie_jar = RequestsCookieJar()
-                request.cookie_jar.update(request['cookies'])
-                del request['cookies']
 
                 self.queue.put(request)
 
